==> haskell-ghc-syntax-highlighter-0.0.9.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-syntax-highlighter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-syntax-highlighter
version:              0.0.9.0
visibility:           public
id:                   ghc-syntax-highlighter-0.0.9.0-Ad4aq4VdMYL5a8Thwd3oas
key:                  ghc-syntax-highlighter-0.0.9.0-Ad4aq4VdMYL5a8Thwd3oas
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/ghc-syntax-highlighter
synopsis:             Syntax highlighter for Haskell using the lexer of GHC
description:          Syntax highlighter for Haskell using the lexer of GHC.
category:             Text
abi:                  ae75e64798142a8ba3da05a51838c787
exposed:              True
exposed-modules:      GHC.SyntaxHighlighter
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-syntax-highlighter
hs-libraries:         HSghc-syntax-highlighter-0.0.9.0-Ad4aq4VdMYL5a8Thwd3oas
depends:
    base-4.17.2.1 ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-syntax-highlighter/html/ghc-syntax-highlighter.haddock

haddock-html:         /usr/share/doc/haskell-ghc-syntax-highlighter/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-syntax-highlighter-0.0.9.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-syntax-highlighter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-syntax-highlighter
version:              0.0.9.0
visibility:           public
id:                   ghc-syntax-highlighter-0.0.9.0-5gRYSNCRjn6X8B9OLNIyf
key:                  ghc-syntax-highlighter-0.0.9.0-5gRYSNCRjn6X8B9OLNIyf
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/ghc-syntax-highlighter
synopsis:             Syntax highlighter for Haskell using the lexer of GHC
description:          Syntax highlighter for Haskell using the lexer of GHC.
category:             Text
abi:                  a8d8dda0d76263b02fe1f72bcfb1d3e3
exposed:              True
exposed-modules:      GHC.SyntaxHighlighter
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-syntax-highlighter
hs-libraries:         HSghc-syntax-highlighter-0.0.9.0-5gRYSNCRjn6X8B9OLNIyf
depends:
    base-4.17.2.1 ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-syntax-highlighter/html/ghc-syntax-highlighter.haddock

haddock-html:         /usr/share/doc/haskell-ghc-syntax-highlighter/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
